@@ -693,6 +693,12 @@ def crms_desc_cli(args):
     for doc in doc_dicts: 
         print(doc["id"])
         print('\tRepository: '+doc['git_repository'])
+        
+        platform = doc['platform']
+        print('\tPlatform')
+        for k in platform.keys():
+            print('\t\t' + k + ': ' + platform[k])
+
         print('\tVersions')
         versions = doc['versions']
         for v in versions :
@@ -732,7 +738,7 @@ def crms_list_cli(args):
         print(doc_id)
     print_verbose(args.verbose, "CRMS LIST Completed !!!")
 
-CRMS_VERSION_STR = "2023.02.16"
+CRMS_VERSION_STR = "2023.03.08.1705"
 
 def crms_ver(verbose=False):
     print_verbose(verbose, "Print Version")
